@@ -15,10 +15,11 @@ from .backends import (
 )
 from .backends.file import EartagFile
 from .utils.bgtask import EartagBackgroundTask, run_threadsafe
-from .utils.misc import find_in_model, cleanup_filename
+from .utils.misc import find_in_model, cleanup_filename, natural_compare
 from .dialogs import (
     EartagRemovalDiscardWarningDialog,
     EartagLoadingFailureDialog,
+    EartagSaveFailureDialog,
     EartagRenameFailureDialog,
 )
 
@@ -70,6 +71,7 @@ def eartagfile_from_path(path):
 
     mimetypes_guess = mimetypes.guess_type(path)[0]
     magic_guess = magic.from_file(path, mime=True)
+
     raise ValueError(
         f"Unsupported file format for file {path} (mimetype: {mimetypes_guess} / {magic_guess})"
     )  # noqa: E501
@@ -140,20 +142,9 @@ class EartagFileManager(GObject.Object):
             except:
                 traceback.print_exc()
                 file_basename = os.path.basename(file.path)
-                self.error_dialog = Adw.MessageDialog(
-                    modal=True,
-                    transient_for=self.window,
-                    heading=_("Failed to save file"),
-                    body=_(
-                        "Could not save file {f}. Check the logs for more information."
-                    ).format(
-                        f=file_basename
-                    ),  # noqa: E501
-                )
-                # TRANSLATORS: "Okay" button in the "failed to save file" dialog
-                self.error_dialog.add_response("ok", _("OK"))
-                self.error_dialog.connect("response", self.close_dialog)
-                self.error_dialog.show()
+                self.error_dialog = EartagSaveFailureDialog(file_basename)
+                self.error_dialog.present(self.window)
+
                 return False
 
         self.window.toast_overlay.add_toast(Adw.Toast.new(_("Saved changes to files")))
@@ -210,7 +201,7 @@ class EartagFileManager(GObject.Object):
         except:
             traceback.print_exc()
             GLib.idle_add(
-                EartagLoadingFailureDialog(self.window, file_basename).present
+                EartagLoadingFailureDialog(file_basename).present, self.window
             )
             return False
 
@@ -323,7 +314,7 @@ class EartagFileManager(GObject.Object):
 
         for file in files:
             if file.is_modified and not force_discard:
-                EartagRemovalDiscardWarningDialog(self, files).present()
+                EartagRemovalDiscardWarningDialog(self, files).present(self.window)
                 return False
 
         self._selection_removed = False
@@ -438,7 +429,7 @@ class EartagFileManager(GObject.Object):
                 self._is_renaming_multiple_files = False
 
                 traceback.print_exc()
-                GLib.idle_add(EartagRenameFailureDialog(self.window, old_path).present)
+                GLib.idle_add(EartagRenameFailureDialog(old_path).present, self.window)
 
                 task.emit_task_done()
                 self.failed = True
@@ -499,7 +490,7 @@ class EartagFileManager(GObject.Object):
         # Step 1. Compare album names
         a_album = GLib.utf8_casefold(a.albumsort or a.album or "", -1)
         b_album = GLib.utf8_casefold(b.albumsort or b.album or "", -1)
-        collate = GLib.utf8_collate(a_album, b_album)
+        collate = natural_compare(a_album, b_album)
 
         # Step 2. Compare track numbers
         if collate == 0:
@@ -512,7 +503,7 @@ class EartagFileManager(GObject.Object):
         if collate == 0:
             a_filename = GLib.utf8_casefold(os.path.basename(a.path), -1)
             b_filename = GLib.utf8_casefold(os.path.basename(b.path), -1)
-            collate = GLib.utf8_collate(a_filename, b_filename)
+            collate = natural_compare(a_filename, b_filename)
 
         return collate
 
