@@ -5,6 +5,7 @@ from gi.repository import Adw, Gtk, Gio, GObject, GdkPixbuf
 
 import os
 import html
+import gettext
 
 from .musicbrainz import (
     acoustid_identify_file,
@@ -477,7 +478,7 @@ class EartagIdentifyRecordingRow(Adw.ActionRow):
 
 
 @Gtk.Template(resource_path=f"{APP_GRESOURCE_PATH}/ui/identify/identify.ui")
-class EartagIdentifyDialog(Adw.Window):
+class EartagIdentifyDialog(Adw.Dialog):
     __gtype_name__ = "EartagIdentifyDialog"
 
     id_progress = Gtk.Template.Child()
@@ -489,7 +490,7 @@ class EartagIdentifyDialog(Adw.Window):
     end_button_stack = Gtk.Template.Child()
 
     def __init__(self, window):
-        super().__init__(modal=True, transient_for=window)
+        super().__init__()
         self.parent = window
         self.file_manager = window.file_manager
 
@@ -534,7 +535,7 @@ class EartagIdentifyDialog(Adw.Window):
             0, self.files.get_n_items(), self.file_manager.selected_files_list
         )
 
-        self.connect("close-request", self.on_close_request)
+        self.connect("closed", self.on_close_request)
 
     def on_close_request(self, *args):
         for row in self.release_rows.values():
@@ -547,17 +548,22 @@ class EartagIdentifyDialog(Adw.Window):
 
     @Gtk.Template.Callback()
     def on_cancel(self, *args):
-        if self.identify_task.is_running:
-            self.identify_task.stop()
-        if self.apply_task.is_running:
-            self.apply_task.stop()
+        try:
+            if self.identify_task.is_running:
+                self.identify_task.stop()
+            if self.apply_task.is_running:
+                self.apply_task.stop()
+        except AttributeError:
+            pass
         self.files = None
+        self.props.can_close = True
         self.close()
 
     @Gtk.Template.Callback()
     def do_identify(self, *args):
         self.identify_button.set_sensitive(False)
         self.apply_button.set_sensitive(False)
+        self.set_can_close(False)
         self.end_button_stack.set_visible_child(self.apply_button)
 
         self.identify_task.reset()
@@ -903,6 +909,7 @@ class EartagIdentifyDialog(Adw.Window):
         except AttributeError:  # this happens when the operation is cancelled
             return
         self.apply_button.set_sensitive(bool(identified))
+        self.set_can_close(True)
         for relrow in self.release_rows.values():
             relrow.toggle_apply_sensitivity(True)
         if not self.files_unidentified.get_n_items():
@@ -913,6 +920,7 @@ class EartagIdentifyDialog(Adw.Window):
         self.apply_button.set_sensitive(False)
         for relrow in self.release_rows.values():
             relrow.toggle_apply_sensitivity(False)
+        self.set_can_close(False)
 
         self.apply_task.reset()
         self.apply_task.run()
@@ -938,6 +946,7 @@ class EartagIdentifyDialog(Adw.Window):
         self.apply_task.emit_task_done()
 
     def on_apply_done(self, *args):
+        self.props.can_close = True
         self.file_manager.emit("refresh-needed")
         try:
             identified = (
@@ -947,9 +956,14 @@ class EartagIdentifyDialog(Adw.Window):
             return
         self.parent.toast_overlay.add_toast(
             Adw.Toast.new(
-                _("Identified {identified} out of {total} tracks").format(
-                    identified=identified, total=self.files.get_n_items()
-                )
+                gettext.ngettext(
+                    # TRANSLATORS: {identified} is a placeholder for the number
+                    # of tracks that were succesfully identified.
+                    # **Do not translate the text between the curly brackets!**
+                    "Identified 1 track",
+                    "Identified {identified} tracks",
+                    identified,
+                ).format(identified=identified)
             )
         )
         self.files = None
