@@ -50,7 +50,7 @@ class Application(Adw.Application):
         win = self.props.active_window
         if not win:
             win = EartagWindow(application=self, paths=self.paths, devel=self.devel)
-        self.create_action("settings", self.on_settings_action, None)
+        self.create_action("preferences", self.on_preferences_action, None)
         self.create_action("about", self.on_about_action, None)
 
         self.create_action("open_file", self.on_open_file_action, "<Ctrl>o")
@@ -65,6 +65,9 @@ class Application(Adw.Application):
         self.create_action("toggle_sidebar", self.on_toggle_sidebar_action, "F9")
         self.create_action("open_menu", self.on_open_menu_action, "F10")
 
+        self.sort_action = self.create_action("sort", self.on_sort_action, None)
+        self.sort_action.set_enabled(False)
+
         self.rename_action = self.create_action("rename", self.on_rename_action, None)
         self.rename_action.set_enabled(False)
 
@@ -105,14 +108,17 @@ class Application(Adw.Application):
     def on_save_action(self, widget, _):
         self.get_active_window().file_manager.save()
 
+    def on_sort_action(self, widget, _):
+        self.get_active_window().run_sort()
+
     def on_rename_action(self, widget, _):
         self.get_active_window().show_rename_dialog()
 
     def on_identify_action(self, widget, _):
         self.get_active_window().show_identify_dialog()
 
-    def on_settings_action(self, widget, _):
-        self.get_active_window().show_settings_dialog()
+    def on_preferences_action(self, widget, _):
+        self.get_active_window().show_preferences_dialog()
 
     def on_extract_action(self, widget, _):
         self.get_active_window().show_extract_dialog()
@@ -128,7 +134,7 @@ class Application(Adw.Application):
         if self.devel:
             version_str += " (dev)"
 
-        about = Adw.AboutWindow(
+        about = Adw.AboutDialog(
             application_name=self._("Ear Tag"),
             application_icon=APP_ID,
             developers=["knuxify"],
@@ -187,10 +193,7 @@ Opened files:
  - {opened_file_list_str}"""
         )
 
-        about.set_modal(True)
-        about.set_transient_for(self.props.active_window)
-
-        about.present()
+        about.present(self.props.active_window)
 
     def on_open_file_action(self, widget, _):
         window = self.get_active_window()
