@@ -17,6 +17,7 @@ from .utils.previewselector import EartagPreviewSelectorButton  # noqa: F401
 from gi.repository import Adw, GLib, Gtk, Gio, GObject, Pango
 import os
 import re
+import gettext
 
 
 def tag_is_int(file, tag):
@@ -33,6 +34,9 @@ def get_formatted_tag(file: "EartagFile", tag: str) -> str:
         value = file.get_property(tag)
         if not value:
             if tag == "title":
+                # TRANSLATORS: Default placeholder string for a missing title
+                # tag, used when renaming files - if the title tag is not
+                # present in the file, this placeholder will be used instead.
                 parsed_value = _("Untitled")
             elif tag_is_int(file, tag):
                 if tag.endswith("tracknumber") or tag.endswith("discnumber"):
@@ -40,6 +44,11 @@ def get_formatted_tag(file: "EartagFile", tag: str) -> str:
                 else:
                     parsed_value = "0"
             else:
+                # TRANSLATORS: Default placeholder string for missing tags,
+                # used when renaming files - if a tag is not present in the
+                # file, this placeholder will be used instead.
+                # {tag_name} is a placeholder for the human-readable tag name.
+                # **Do not change the text between the curly brackets!**
                 parsed_value = _("Unknown {tag_name}").format(tag_name=TAG_NAMES[tag])
 
         else:
@@ -58,8 +67,7 @@ def get_formatted_tag(file: "EartagFile", tag: str) -> str:
                 # potential file path separators we need to filter out first,
                 # otherwise they'll get treated as folders (valid as far as
                 # renaming and moving to a folder is concerned).
-                for char in ("/", "'", ":"):
-                    parsed_value = parsed_value.replace(char, "_")
+                parsed_value = parsed_value.replace("/", "_")
 
     return parsed_value
 
@@ -84,7 +92,6 @@ def parse_placeholder_string(
     n = 0
     offset = 0
     out = placeholder
-    present_tags = set()
     _positions = []
     for match in re.finditer(r"{.*?}".encode("utf-8"), placeholder):
         try:
@@ -95,14 +102,12 @@ def parse_placeholder_string(
         if "{" in tag_name or "}" in tag_name:
             continue
 
-        if tag_name == "" or tag_name in present_tags:
+        if tag_name == "":
             continue
 
         if tag_name not in VALID_TAGS + ("length", "bitrate"):
             continue
 
-        present_tags.add(tag_name)
-
         formatted_value = get_formatted_tag(file, tag_name).encode("utf-8")
         out = out.replace(("{" + tag_name + "}").encode("utf-8"), formatted_value, 1)
 
@@ -123,7 +128,7 @@ def parse_placeholder_string(
 
 
 @Gtk.Template(resource_path=f"{APP_GRESOURCE_PATH}/ui/rename.ui")
-class EartagRenameDialog(Adw.Window):
+class EartagRenameDialog(Adw.Dialog):
     __gtype_name__ = "EartagRenameDialog"
 
     toast_overlay = Gtk.Template.Child()
@@ -147,11 +152,13 @@ class EartagRenameDialog(Adw.Window):
 
     tag_selector = Gtk.Template.Child()
 
-    def __init__(self, window):
-        super().__init__(modal=True, transient_for=window)
-        self.file_manager = window.file_manager
+    def __init__(self, parent):
+        super().__init__()
+        self.parent = parent
+        self.file_manager = parent.file_manager
         self._folder = None
         self._has_sandboxed_files = False
+        self._renamed = 0
 
         self.files = self.file_manager.selected_files_list.copy()
         for file in self.files:
@@ -260,7 +267,7 @@ class EartagRenameDialog(Adw.Window):
     @Gtk.Template.Callback()
     def show_folder_selector(self, *args):
         self.folder_chooser.select_folder(
-            self, None, self.select_folder_from_selector, None
+            self.parent, None, self.select_folder_from_selector, None
         )
 
     def select_folder_from_selector(self, source, result, data):
@@ -298,6 +305,7 @@ class EartagRenameDialog(Adw.Window):
         self.preview_selector_button.disconnect(self._preview_update_conn)
         self.preview_selector_button.teardown()
         self.files = None
+        self.set_can_close(True)
         self.close()
 
     @Gtk.Template.Callback()
@@ -322,7 +330,9 @@ class EartagRenameDialog(Adw.Window):
             )
 
         self.set_sensitive(False)
+        self.set_can_close(False)
 
+        self._renamed = len(self.files)
         self.file_manager.rename_files(self.files, names)
 
     # Preview
@@ -361,10 +371,23 @@ class EartagRenameDialog(Adw.Window):
         self.preview_entry.set_attributes(preview_attrs)
 
     def on_done(self, task, *args):
+        self.set_can_close(True)
         if task.failed:
             self.set_sensitive(True)
             self.error_banner.set_revealed(True)
         else:
+            self.parent.toast_overlay.add_toast(
+                Adw.Toast.new(
+                    gettext.ngettext(
+                        # TRANSLATORS: {renamed} is a placeholder for the number
+                        # of tracks the tags were succesfully extracted for.
+                        # **Do not translate the text between the curly brackets!**
+                        "Renamed 1 file",
+                        "Renamed {renamed} files",
+                        self._renamed,
+                    ).format(renamed=self._renamed)
+                )
+            )
             self.files = None
             self.close()
 
